Coverage for .tox/cov/lib/python3.11/site-packages/confattr/__init__.py: 100%

1#!./runmodule.sh

2

3'''

4 Config Attributes

5

6 A python library to read and write config files

7 with a syntax inspired by vimrc and ranger config.

8'''

9

10 __version__ = '1.0.2-dev'

11

12 from .config import Config, ExplicitConfig, DictConfig, MultiConfig, MultiDictConfig, ConfigId, TimingError

13 from .configfile import ConfigFile, NotificationLevel, Message, ParseException, MultipleParseExceptions, ConfigFileCommand, ConfigFileArgparseCommand, FormattedWriter, ConfigFileWriter, HelpWriter, SectionLevel, UiNotifier

14 from .formatters import Primitive, Hex, List, Set, Dict

15

16 try:

17 from .configfile import SaveKwargs

18 except ImportError: # pragma: no cover

19 pass

20

21

22 __all__ = [

23 # -------- for normal usage -------

24 # imported from config

25 'Config',

26 'ExplicitConfig',

27 'DictConfig',

28 'MultiConfig',

29 'MultiDictConfig',

30 'ConfigId',

31 # imported from configfile

32 'ConfigFile',

33 'NotificationLevel',

34 'Message',

35 'ParseException',

36 'MultipleParseExceptions',

37 'UiNotifier',

38 # imported from formatters

39 'Primitive',

40 'Hex',

41 'List',

42 'Set',

43 'Dict',

44 ## -------- for extending/customizing this package -------

45 # imported from config

46 'TimingError',

47 # imported from configfile

48 'SectionLevel',

49 'FormattedWriter',

50 'ConfigFileWriter',

51 'HelpWriter',

52 'SaveKwargs',

53 'ConfigFileCommand',

54 'ConfigFileArgparseCommand',

55]